======
CRUTCH
======

Have you ever had this moment when you wanted to write a small tool or just try
some new algorithm but the thought of assembling a proper project folder
structure spoiled the desire...

Crutch is a small-size project generator that allows you to create, build and
test a project

.. contents::

Installation
============

From pip::

  $ pip install -e <crutch>


Usage
=====

To create a project within an existing directory::

  $ crutch new <type>

To build and test the project within its directory::

  $ crutch build


Types
-------------

In Progress::

  cpp
  python

In Future::

  c#
  java
  vim
  ...
